<div align="center">
    <img src="../../docs/images/logo-title.png" height="80px">
    <h3>The Graph Of LIfe Library.</h3>
</div>


## What is in this folder? 

code for positional encoder networks for positional encodings and structural encodings

- ✅ `base_encoder.py`: `BaseEncoder` class should be inherented by all positional encoder networks
- ✅ `mlp_encoder.py`: `MLPEncoder` as a simple MLP encoder for any positional encoding
- `gaussian_kernal_pos_encoder.py`: `GaussianKernalPosEncoder` class for gaussian kernal positional encoder
- `laplace_pos_encoder.py`: `LapPENodeEncoder` class for laplacian eigenvector and eigenvalue encoding
